@@ -6,7 +6,7 @@ use MooseX::Types::ISO8601 qw/ ISO8601DateTimeStr /;
 use Sys::Hostname ();
 use namespace::clean -except => 'meta';
 
-our $VERSION = '0.003';
+our $VERSION = '0.004';
 $VERSION = eval $VERSION;
 
 use overload
@@ -15,7 +15,7 @@ use overload
 
 with Storage('format' => 'JSON');
 
-my $GETOPT = do { local $@; Class::MOP::load_class('MooseX::Getopt'); 1 };
+my $GETOPT = do { local $@; eval { require MooseX::Getopt; 1 } };
 
 has epochtime => (
     isa => 'Int',
